<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="248"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>Nteekateeka za Saawa ya Nsi Yonna</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>&amp;Endabika ya saawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>&amp;Ssaawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>E&amp;mpandika:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>Mu bufunze</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>Mu bujjuvu</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation>Gyewetegekera</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>Laga s&amp;ikonda</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>Ess&amp;aawa ez&apos;ennamba emu yokka ziteekeko zero ekulembera</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>Essaawa ezi&amp;kozesebwa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>&amp;We ziwandikibwa:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>E&amp;mpandika ya zo:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>Wansi w&apos;essaawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>Waggulu w&apos;essaawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>Zikulembere ssaawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>Ziddirire essaawa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>Nga enjawulo ku UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>Nga erinnya effunze</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>Nga erinnya eriva mu IANA</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="591"/>
        <source>Custom name</source>
        <translation>Nga erinnya lwe weyiiyiza</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>Ko&amp;zesa empandika ya saawa 12</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>Nga ekiraga ekifo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>La&amp;ga nnaku za mwezi</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>We zi&amp;naalabikira:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>Em&amp;pandika ya zo:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>ISO 8601</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>&amp;Laga mwaka</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>Laga l&amp;unaku lwa wiiki</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>Ennamba &amp;y&apos;olunaku eya digiti emu giteekeko zero ekulembera</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>Amannya g&apos;emyezi n&apos;ennaku za wiiki gawandike mu bu&amp;jjuvu</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>Empandika y&apos;obudde giteekateeke na bino ebyetaagisa obumanyiri&amp;vu</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customize ...</source>
        <translation>Wetegeke&amp;re empandika...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>Essaawa e&amp;zikozeseka</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>&amp;Londayo...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>K&amp;igyemu</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>Zifuule eza &amp;bulijjo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>&amp;Kyetegekere erinnya...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation>&amp;Yambusa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation>&amp;Ssa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="518"/>
        <source>Change displayed time zone with mouse wheel</source>
        <translation>Kozesa namuziga ya ku kasongesebwa okukyusa essaawa ezikozesebwa eziragibwa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="525"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Middle-click the clock to view the time and date for all configured timezones.</source>
        <translation>&lt;b&gt;Genderera:&lt;/b&gt; Akasonga bw&apos;okateeka ku ssaawa n&apos;onyiga eppeesa ly&apos;akasongesebwa erya wakati ekulaga obudde n&apos;ennaku ebya mu buli ttwale ly&apos;obudde eritegekedwa ku sisitemu yo.</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="536"/>
        <source>&amp;General</source>
        <translation>E&amp;bya wamu</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="542"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>&amp;Essaawa yetereeze olubaawo bwe lubeera busimbalaala</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="552"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>&amp;Kalenda erage n&apos;ennamba za wiiki</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="562"/>
        <source>S&amp;how tooltip</source>
        <translation>&amp;Akaboozi ak&apos;ongera okutangaaza kabonekenga</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="108"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="590"/>
        <source>Input custom time zone name</source>
        <translation>Wandika erinnya ly&apos;e weyiiyizza</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>Kweteekateekera empandika ya mu Saawa ya Nsi Yonna</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt;Amateeka agafuga empandika y&apos;ennaku n&apos;essaawa gye weteekateekera&lt;/h1&gt;
&lt;p&gt;Olutiba lw&apos;empandika y&apos;essaawa n&apos;ennaku zibeera ennukuta engattike eziraga aw&apos;okuwandika oba okusoma ebipimo by&apos;obudde mu mboozi oba mu data eya kompyuta. Mu bibalibwa ng&apos;ebipimo by&apos;obudde mwe muli sikonda, ddakiika, saawa, nnaku, myezi, myaka, byaasa n&apos;ebipimo ebirala okutuukira ddala ku mirembe.&lt;/p&gt;
&lt;p&gt;Endagiriro edda ku bino ekulaga ennukuta ezeyambisibwa mu kutegeka entiba ez&apos;empandika y&apos;essaawa n&apos;ennaku era n&apos;ekulaga amakulu n&apos;enkozesa bya go.&lt;/p&gt;
&lt;p&gt;Olutiba lusobola okuzingiramu ebigambo byennyini nga ennukuta za byo zo ssi biragiro wabula ekigambo kya kulabikira muli mu ssaawa n&apos;ennaku ebiwandikidwa oba ebisomedwa kompyuta. Mu lutiba ekigambo kikulemberwa akabonero &apos; era ne kifundikibwa akabonero &apos; nga ekyo kiraga we kitandika ne we kikoma. Ekyokulabirako olutiba &apos;Saawa&apos; h &apos;ne dakiika&apos; m luvamu essawa nga zifaanana bwezityi: Saawa 9 ne dakiika 30. Sso olutiba h m luviiramu esasaawa ze zimu okuwandikibwa bwezityi: 9 30. Bw&apos;obeera oyagala akabonero ako kennyini kalabike olina okuwandikawo bubiri, bwebutyi, &apos;&apos;.&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Ennukuta&lt;/th&gt;&lt;th&gt;Makulu&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;Kitegeeza namba ya lunaku nga eziri wansi wa kkumi tekuli zero ekulembera (1 okutuuka ku 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;Kitegeeza namba ya lunaku nga eziri wansi wa kkumi ziriko zero ekulembera (01 okutuuka ku 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;Kitegeeza linnya lya lunaku lwa wiiki mu lulimi olukolebwamu nga lifunzidwa mu nnukuta ssatu (nga &apos;Bal&apos; okutuuka ku &apos;Sab&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;Kitegeeza linnya lya lunaku lwa wiiki mu lulimi olukolebwamu mu bujjuvu (nga &apos;Balaza&apos; okutuuka ku &apos;Sabbiiti&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;Kitegeeza namba y&apos;omwezi nga egiri wansi wa kkumi tekuli zero ekulembera (1 okutuuka ku 12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;Kitegeeza namba y&apos;omwezi nga egiri wansi wa kkumi kuliko zero ekulembera (01okutuuka ku 12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;Kitegeeza linnya lya lmwezii mu lulimi olukolebwamu nga lifunzidwa mu nnukuta ssatu (nga &apos;Jan&apos; okutuuka ku &apos;Des&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;Kitegeeza linnya lya lmwezii mu lulimi olukolebwamu mu bujjuvu (e.g. &apos;Janwariyo&apos; okutuuka ku &apos;Desemba&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;Kitegeeza mwaaka nga guwandikwa nga ennamba zagwo ezisembayo bbiri (okuva ku 00 okutuuka ku 99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;Kitegeeza mwaaka nga guwandikwa nga ennamba zagwo zonna nya&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;Kitegeeza ssaawa nga ezitatuuka mu kkumi tekuli zero ekulembera (0 okutuuka ku 23 oba 1 okutuuka ku 12 mu mpandika ya AM/PM)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;Kitegeeza ssaawa nga ezitatuuka mu kkumi ziriko zero ekulembera (00 okutuuka ku 23 oba 01 okutuuka ku 12 mu mpandika ya AM/PM)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;Kitegeeza ssaawa nga ezitatuuka mu kkumi tekuli zero ekulembera mu mpandika ya ssaawa 24 (0 okutuuka ku 23, ne mu mpandika ya AM/PM)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;Kitegeeza ssaawa nga ezitatuuka mu kkumi ziriko zero ekulembera mu mpandika ya ssaawa 24 (00 okutuuka ku 23, ne mu mpandika ya AM/PM)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;Kitegeeza ddakiika nga ezitatuuka mu kkumi tekuli zero ekulembera (0 okutuuka ku 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;Kitegeeza ddakiika nga ezitatuuka mu kkumi ziriko zero ekulembera (00 okutuuka ku 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;Kitegeeza sikonda nga ezitatuuka mu kkumi tekuli zero ekulembera (0 okutuuka ku 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;Kitegeeza sikonda nga ezitatuuka mu kkumi ziriko zero ekulembera (00 okutuuka ku 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;oba&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;Kitegeeza kozesa empandika eya AM/PM. Awali ennukuta &lt;b&gt;A/AP&lt;/b&gt; wajjakuddawo &quot;AM&quot; oba &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;Kitegeeza kozesa empandika eya am/pm. Awali ennukuta &lt;b&gt;a/ap&lt;/b&gt; wwajjakuddawo &quot;am&quot; oba &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya ly&apos;ekitundu ky&apos;ensi essaawa we zikolera (e.g. &quot;EAT&quot; ssaawa ezibalibwa mu Afirika y&apos;ebuvanjuba - omuli Uganda, Kenya ne Tanzania)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;Kitegeeza enjawulo okuva ku ssaawa za UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya aba IANA lye baawa ekifo essaawa mwe zikolera&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya ery&apos;ekifo essaawa mwe zikolera effunze&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya ery&apos;ekifo essaawa mwe zikolera erimpi&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya ery&apos;ekifo essaawa mwe zikolera erijjuvu&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;Kitegeeza erinnya lye weyiiyizza ekifo essaawa mwe zikolera. Lino oliwandikira mu katimbe aka &apos;Bifo essaawa mwe zikolera&apos;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Genderera:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Olutiba bw&apos;oluteekamu obubonero obutali mu lubu lwa [&apos;a&apos;..&apos;z&apos;] oba [&apos;A&apos;..&apos;Z&apos;] bujja okubalibwa ng&apos;ebigambo byennyini sso ssi biragiro. Okugeza, obubonero nga &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; ne &apos;@&apos; bujja okulabikira mu biwandikidwa nga bwo bwennyini nandibadde tebuwerekedwa obubonero bwa &apos; .&lt;/li&gt;&lt;li&gt;Ekipimo eky&apos;obudde ekisinga obutono essaawa eno ky&apos;ekyukirako ye sikonda 1. Ennukuta &apos;z&apos; etegeeza kitundu kimu kya lukumi ekya sikonda. Singa olutiba lw&apos;empandika y&apos;essaawa n&apos;ennaku lubeeramu &apos;z &apos;oba &apos;zzz&apos; essaawa ejjakulaga obutundu obwo naye ejjakulindanga lukumi luyitewo eryoke erage nti obudde bukyuse (ekigiyamba okukola mu ngeri etamatiza).&lt;/li&gt;&lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>Lukalala lw&apos;essaawa ezikozesebwa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>Ssaawa ezikozesebwa</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>Linnya lya zo</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>Kutangaaza</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>Nsi mwe zikolera</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>Endala</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>Essaawa ez&apos;omu katundu</translation>
    </message>
</context>
</TS>
